//
//  SingleSubChannelQueryView.swift
//  SampleApp
//
//  Created by Amity on 7/11/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import Foundation
import SwiftUI
import AmitySDK

extension AmitySubChannel: Identifiable {
    
    public var id: String {
        return self.subChannelId
    }
}

struct SingleSubChannelQueryView: View {
    
    @State var subChannelId = ""
    @State var subChannelName = ""
    
    @State private var isAlertShown = false
    @State private var alertMessage: String = ""
    
    @State private var showEditScreen: Bool = false
        
    @StateObject var viewModel = SubChannelManager()
    
    @State private var subChannels = [AmitySubChannel]()
    
    var body: some View {
        VStack {
            TextField("Sub Channel Id", text: $subChannelId)
                .modifier(AmityTextFieldStyle())
                .keyboardType(.default)
                .autocapitalization(.none)
            
            AmityDefaultButton(title: "Query") {
                viewModel.fetchSubChannel(id: subChannelId) { subChannel, error in
                    
                    if let error {
                        alertMessage = "Error while fetching subchannel: \(error.localizedDescription)"
                        isAlertShown = true
                    } else if let subChannel {
                        self.subChannels = [subChannel]
                    }
                }
            }
            .padding(.top, 16)
            
            Divider()
                .frame(width: 100)
                .padding(.vertical, 16)
            
            List(subChannels) { item in
                VStack(alignment: .leading) {
                    Text(item.displayName)
                        .font(.headline)
                        .padding(.bottom, 4)
                    Text("Id: \(item.subChannelId)")
                    Text("Channel Id: \(item.channelId)")
                    Text("Deleted: \(item.isDeleted ? "True" : "False")")
                    Text("Creator Id: \(item.creatorId)")
                }
                .onTapGesture {
                    // Popuplate id & name
                    subChannelId = item.subChannelId
                    subChannelName = item.displayName
                    
                    // Show option to edit & delete
                    showEditScreen = true
                }
            }
            .listStyle(.plain)
        }
        .padding()
        .navigationBarTitle("Get SubChannel", displayMode: .inline)
        .alert(isPresented: $isAlertShown) {
            Alert(title: Text(""), message: Text(alertMessage), dismissButton: .cancel(Text("Dismiss")))
        }
        .sheet(isPresented: $showEditScreen) {
            NavigationView {
                EditSubChannelView(viewModel: viewModel, subChannelId: subChannelId, subChannelName: subChannelName)
                    .navigationTitle("Edit Sub-Channel")
                    .navigationBarTitleDisplayMode(.inline)
            }
        }
        
    }
}

struct SingleSubChannelQueryView_Previews: PreviewProvider {
    static var previews: some View {
        SingleSubChannelQueryView()
    }
}
