//
//  FeedPostVideoCell.swift
//  SampleApp
//
//  Created by Nontapat Siengsanor on 22/8/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//


import UIKit

protocol FeedPostVideoCellDelegate: AnyObject {
    func didTapVideo(_ cell: FeedPostVideoCell, videoInfo: VideoFeedModel.VideoInfo)
}

class FeedPostVideoCell: UITableViewCell {
    
    weak var delegate: FeedPostVideoCellDelegate?
    
    var videoFeedModel: VideoFeedModel? {
        didSet {
            collectionView.reloadData()
        }
    }
    weak var feedManager: UserPostsFeedManager?
    
    @IBOutlet weak var imageCountLabel: UILabel!
    @IBOutlet weak var collectionView: UICollectionView!
    
    override func awakeFromNib() {
        super.awakeFromNib()
        selectionStyle = .none
        collectionView.dataSource = self
        collectionView.delegate = self
    }
    
    override func prepareForReuse() {
        super.prepareForReuse()
        videoFeedModel = nil
    }
    
    private var videoInfos: [VideoFeedModel.VideoInfo] {
        return videoFeedModel?.videoInfos ?? []
    }
    
}

extension FeedPostVideoCell: UICollectionViewDataSource {
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return videoInfos.count
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: "FeedPostVideoCollectionCell", for: indexPath) as! FeedPostVideoCollectionCell
        
        let videoInfo = videoInfos[indexPath.item]
        if let status = videoInfo.videoData.status {
            cell.label.text = "\(status)"
        }
        
        let session = UUID().uuidString
        cell.session = session
        if let thumbnailFileUrl = videoInfo.thumbnailInfo?.fileURL {
            feedManager?.downloadImage(fileUrl: thumbnailFileUrl) { image in
                if cell.session == session {
                    cell.imageView.image = image
                }
            }
        }
        
        return cell
    }
    
}

extension FeedPostVideoCell: UICollectionViewDelegate {
    func collectionView(_ collectionView: UICollectionView, didSelectItemAt indexPath: IndexPath) {
        delegate?.didTapVideo(self, videoInfo: videoInfos[indexPath.item])
    }
}

class FeedPostVideoCollectionCell: UICollectionViewCell {
    var session = UUID().uuidString
    @IBOutlet weak var imageView: UIImageView!
    @IBOutlet weak var label: UILabel!
    
    override func awakeFromNib() {
        super.awakeFromNib()
        imageView.contentMode = .scaleAspectFill
    }
    
    override func prepareForReuse() {
        super.prepareForReuse()
        imageView.image = nil
        label.text = ""
    }
}

